Crate opentalk_client_shared
source ·Expand description
Types and traits that are used by the OpenTalk client library crate
Structs
- Wrapper type that adds authorization information to a request
- SNAFU context selector for the
ApiError::Clientvariant - A wrapper around
Optionfor deserializing from optional data from a HTTP response. - SNAFU context selector for the
ApiError::DataTypevariant - SNAFU context selector for the
ApiError::OpenTalkServicevariant - SNAFU context selector for the
ApiError::OpenTalkvariant - SNAFU context selector for the
ApiError::Unauthorizedvariant
Enums
- Errors which may occur when using API endpoints.
Traits
- Trait for augmenting requests with authentication information
- A trait representing an asynchronous client which can communicate with an OpenTalk instance.
- A trait representing a client which can communicate with an OpenTalk instance via REST.
- Trait for adding authorization information to http requests